#!/usr/bin/env python

from distutils.core import setup

setup(name='scrubber',
      version='1.1',
      description='A whitelisting HTML scrubber',
      url='http://github.com/samuel/python-scrubber/tree/master',
      packages=['scrubber'],
     )
